@@ -1,7 +1,7 @@
 class Stl:
 
-    def __init__(self, arr):
-        self.arr = arr
+    def __init__(self):
+        pass
 
     def find(self, arr):
         biggest = arr[0] 
@@ -14,11 +14,11 @@ class Stl:
 
         return biggest_index
 
-    def sort(self):
+    def sort(self, arr):
         new_arr = []
 
-        for i in range(len(self.arr)):
-            biggest = self.find(self.arr)
-            new_arr.append(self.arr.pop(biggest))
+        for i in range(len(arr)):
+            biggest = self.find(arr)
+            new_arr.append(arr.pop(biggest))
 
         return new_arr
\ No newline at end of file
